OC.L10N.register(
    "federatedfilesharing",
    {
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Ali želite dodati oddaljeno mesto uporabe {name} uporabnika {owner}@{remote}?",
    "Remote share" : "Oddaljeno mesto za souporabo",
    "Remote share password" : "Geslo za oddaljeno souporabo",
    "Cancel" : "Prekliči",
    "Add remote share" : "Dodaj oddaljeno mesto za souporabo",
    "Copy" : "Kopiraj",
    "Copied!" : "Kopirano!",
    "Not supported!" : "Ni podprto!",
    "Press ⌘-C to copy." : "Pritisnite ⌘-C za kopiranje.",
    "Press Ctrl-C to copy." : "Pritisnite Ctrl-C za kopiranje.",
    "Invalid Federated Cloud ID" : "Neveljaven ID zveznega oblaka",
    "Server to server sharing is not enabled on this server" : "Na tem strežniku souporaba s strežnika na strežnik ni omogočena.",
    "Couldn't establish a federated share." : "Ni mogoče vzpostaviti zveznega mesta za souporabo.",
    "Couldn't establish a federated share, maybe the password was wrong." : "Zvezne povezave za souporabo ni mogoče ustvariti. Morda je navedeno napačno geslo.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "Zvezne povezave za souporabo ni mogoče ustvariti. Kaže, da je podana zahteva za povezavo z nepodprto staro različico oblaka (Nextzcloud ≤ 9).",
    "Not allowed to create a federated share with the same user" : "Ni dovoljeno ustvariti mesta souporabe zveznega oblaka z istim uporabnikom",
    "File is already shared with %s" : "Datoteka je že v souporabi pri %s",
    "Could not find share" : "Mape v souporabi ni mogoče najti",
    "Federated sharing" : "Souporaba v zveznem oblaku",
    "Accept" : "Sprejmi",
    "Decline" : "Zavrni",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Omogoči souporabo prek #Določila ID zveznega oblaka Nextcloud; več na %s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Omogoči souporabo prek #Določila ID zveznega oblaka Nextcloud",
    "Sharing" : "Souporaba",
    "Federated file sharing" : "Souporaba v zveznem oblaku",
    "Provide federated file sharing across servers" : "Omogoči zvezno souporabo prek različnih strežnikov",
    "Federated Cloud Sharing" : "Souporaba zveznega oblaka",
    "Open documentation" : "Odpri dokumentacijo",
    "Adjust how people can share between servers." : "Določila, kako lahko uporabniki omogočajo souporabo med različnimi strežniki.",
    "Allow users on this server to send shares to other servers" : "Dovoli uporabnikom tega strežnika pošiljanje map za souporabo na druge strežnike.",
    "Allow users on this server to receive shares from other servers" : "Dovoli uporabnikom tega strežnika sprejemanje map za souporabo z drugih strežnikov.",
    "Allow users on this server to send shares to groups on other servers" : "Dovoli uporabnikom tega strežnika pošiljanje map za souporabo za skupine na drugih strežnikih.",
    "Search global and public address book for users" : "Preišči javne in splošne imenike za uporabnike",
    "Federated Cloud" : "Zvezni oblak",
    "Your Federated Cloud ID:" : "ID zveznega oblaka:",
    "Add to your website" : "Dodaj na spletišče",
    "Share with me via Nextcloud" : "Omogoči souporabo prek oblaka Nextcloud",
    "HTML Code:" : "Koda HTML:"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
